summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmwarpedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmwarpedit.h')
-rw-r--r--kpovmodeler/pmwarpedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmwarpedit.h b/kpovmodeler/pmwarpedit.h
index 653219b9..00becf67 100644
--- a/kpovmodeler/pmwarpedit.h
+++ b/kpovmodeler/pmwarpedit.h
@@ -44,9 +44,9 @@ class PMWarpEdit : public PMDialogEditBase
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMWarpEdit with tqparent and name
*/
- PMWarpEdit( TQWidget* tqparent, const char* name = 0 );
+ PMWarpEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -44,9 +44,9 @@ class PMWarpEdit : public PMDialogEditBase
public:
/**
- * Creates a PMWarpEdit with tqparent and name
+ * Creates a PMWarpEdit with parent and name
*/